PointsAnnotation

Struct PointsAnnotation 

pub struct PointsAnnotation {
    pub timestamp: Option<Timestamp>,
    pub type: i32,
    pub points: Vec<Point2>,
    pub outline_color: Option<Color>,
    pub outline_colors: Vec<Color>,
    pub fill_color: Option<Color>,
    pub thickness: f64,
    pub metadata: Vec<KeyValuePair>,
}
Fields

timestamp: Option<Timestamp>

Timestamp of annotation

type: i32

Type of points annotation to draw

points: Vec<Point2>

Points in 2D image coordinates (pixels). These coordinates use the top-left corner of the top-left pixel of the image as the origin.

outline_color: Option<Color>

Outline color

outline_colors: Vec<Color>

Per-point colors, if type is POINTS, or per-segment stroke colors, if type is LINE_LIST, LINE_STRIP or LINE_LOOP.

fill_color: Option<Color>

Fill color

thickness: f64

Stroke thickness in pixels

metadata: Vec<KeyValuePair>

Additional user-provided metadata associated with this annotation. Keys must be unique.

Implementations

Source

impl PointsAnnotation

pub fn type(&self) -> Type

Returns the enum value of type, or the default if the field is set to an invalid enum value.

pub fn set_type(&mut self, value: Type)

Sets type to the provided enum value.