pub struct ConnectionGraph { /* private fields */ }Available on crate features
remote-access or websocket only.Expand description
A connection graph describing a topology of subscribers, publishers, topics, and services.
Connection graph data can be published with publish_connection_graph, and visualized in the Foxglove Topic Graph panel.
Implementations
Sourceimpl ConnectionGraph
impl ConnectionGraph
Sourcepub fn set_published_topic(
&mut self,
topic: impl Into<String>,
publisher_ids: impl IntoIterator<Item = impl Into<String>>,
)
pub fn set_published_topic( &mut self, topic: impl Into<String>, publisher_ids: impl IntoIterator<Item = impl Into<String>>, )
Set a published topic and its associated publisher ids.
Overwrites any existing topic with the same name.
Sourcepub fn set_subscribed_topic(
&mut self,
topic: impl Into<String>,
subscriber_ids: impl IntoIterator<Item = impl Into<String>>,
)
pub fn set_subscribed_topic( &mut self, topic: impl Into<String>, subscriber_ids: impl IntoIterator<Item = impl Into<String>>, )
Set a subscribed topic and its associated subscriber ids.
Overwrites any existing topic with the same name.
Sourcepub fn set_advertised_service(
&mut self,
service: impl Into<String>,
provider_ids: impl IntoIterator<Item = impl Into<String>>,
)
pub fn set_advertised_service( &mut self, service: impl Into<String>, provider_ids: impl IntoIterator<Item = impl Into<String>>, )
Set an advertised service and its associated provider ids.
Overwrites any existing service with the same name.